@@ -3,31 +3,43 @@ package Finance::Bitcoin::Wallet;
 use 5.010;
 use common::sense;
 use Carp;
-use Class::Accessor 'antlers';
 use Finance::Bitcoin;
+use Any::Moose;
+use Object::AUTHORITY;
 use Scalar::Util qw[blessed];
 
-our $VERSION = '0.003';
-
-BEGIN { foreach my $method (qw[api]) { eval "sub $method {}" } } # make visible to Pod::Coverage
+BEGIN {
+	$Finance::Bitcoin::Wallet::AUTHORITY = 'cpan:TOBYINK';
+	$Finance::Bitcoin::Wallet::VERSION   = '0.004';
+}
 
 has api => (is => 'rw');
 
-sub new
+around BUILDARGS => sub
 {
-	my ($class, $api) = @_;
-	
-	unless (blessed($api) and $api->isa('Finance::Bitcoin::API'))
+	my $orig  = shift;
+	my $class = shift;
+
+	if (scalar @_ == 1
+	and (blessed($_[0]) || $_[0] =~ /^http/))
 	{
-		$api = $api ? 
-			Finance::Bitcoin::API->new(endpoint=>"$api") : 
-			Finance::Bitcoin::API->new;
+		my ($api) = @_;
+
+		unless (blessed($api) and $api->isa('Finance::Bitcoin::API'))
+		{
+			$api = $api ? 
+				Finance::Bitcoin::API->new(endpoint=>"$api") : 
+				Finance::Bitcoin::API->new;
+		}
+
+		return $class->$orig(api => $api);
 	}
 	
-	my $self = bless {
-		api   => $api ,
-		}, $class;
-}
+	else
+	{
+		return $class->$orig(@_);
+	}
+};
 
 sub balance
 {
